@@ -186,7 +186,7 @@ class Dxr_Subscriber:
     def __init__(self, topic, callback):
         global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc, sn
         if sn is not None:
-            topic = '/' + sn + topic
+            topic = '/' + sn + '/client' + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
@@ -230,7 +230,7 @@ class Dxr_Publisher:
     def __init__(self, topic):
         global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit, mqttc, sn
         if sn is not None:
-            topic = '/' + sn + topic
+            topic = '/' + sn + '/pc' + topic
         if mqttc is None:
             mqttc = Mqtt()
         if isinstance(topic, str):
